#' @title available models
#' @export
#' @examples
#' data(availableModels)
#' availableModels
availableModels <- c("celda_C", "celda_G", "celda_CG")

#' A toy count matrix for use with celda.
#'
#' @title sampleCells
#' @description A matrix of simulated gene counts.
#' @format A matrix of simulated gene counts with 10 rows (genes) and 10
#'  columns (cells).
#' @details Generated by Josh Campbell.
#' @source \url{http://github.com/campbio/celda}
"sampleCells"

#' An example simulated count matrix from the celda_CG model.
#'
#' @title celdaCGSim
#' @format A list of counts and properties as returned from simulateCells().
#' @examples
#' celdaCGSim <- simulateCells("celda_CG")
"celdaCGSim"

#' celda_CG results generated from celdaCGSim
#'
#' @title celdaCGmod
#' @format A celda_CG object
#' @examples
#' data(celdaCGSim)
#' celdaCGMod <- celda_CG(celdaCGSim$counts,
#'   K = celdaCGSim$K,
#'   L = celdaCGSim$L,
#'   nchains = 1
#' )
"celdaCGMod"

#' Example results of celdaGridSearch on celdaCGSim
#' @title celdaCGGridSearchRes
#' @format An object as returned from celdaGridSearch()
#' @examples
#' data(celdaCGSim)
#' celdaCGGridSearchRes <- celdaGridSearch(celdaCGSim$counts,
#'   model = "celda_CG",
#'   paramsTest = list(K = seq(4, 6), L = seq(9, 11)),
#'   paramsFixed = list(sampleLabel = celdaCGSim$sampleLabel),
#'   bestOnly = TRUE,
#'   nchains = 1,
#'   cores = 2
#' )
"celdaCGGridSearchRes"


#' An example simulated count matrix from the celda_C model.
#'
#' @title celdaCSim
#' @format A list of counts and properties as returned from simulateCells().
#' @examples
#' celdaCSim <- simulateCells("celda_C")
"celdaCSim"

#' celda_C results generated from celdaCSim
#'
#' @title celdaCMod
#' @format A celda_C object
#' @examples
#' data(celdaCSim)
#' celdaCMod <- celda_C(celdaCSim$counts, K = celdaCSim$K, nchains = 1)
"celdaCMod"

#' An example simulated count matrix from the celda_G model.
#'
#' @title celdaGSim
#' @format A list of counts and properties as returned from simulateCells()
#' @examples
#' celdaGSim <- simulateCells("celda_G")
"celdaGSim"

#' celda_G results generated from celdaGsim
#'
#' @title celdaGMod
#' @format A celda_G object
#' @examples
#' data(celdaGSim)
#' celdaGMod <- celda_G(celdaGSim$counts, L = celdaGSim$L, nchains = 1)
"celdaGMod"

#' A toy contamination data generated by simulateContaminatedMatrix
#'
#' @title contaminationSim
#' @description Generated by simulateContaminatedMatrix
#' @format A list
"contaminationSim"
